const char* _ServiceData_json = "{\"brand\":\"GENERIC\",\"model\":\"Service data\",\"model_id\":\"ServiceData\",\"condition\":[\"uuid\",\"index\",0,\"180f\"],\"properties\":{\"batt\":{\"decoder\":[\"value_from_hex_data\",\"servicedata\",0,2,false,false]}}}";
/*R""""(
{
   "brand":"GENERIC",
   "model":"Service data",
   "model_id":"ServiceData",
   "condition":["uuid", "index", 0, "180f"],
   "properties":{
      "batt":{
         "decoder":["value_from_hex_data", "servicedata", 0, 2, false, false]
      }
   }
})"""";*/

const char* _ServiceData_json_props = "{\"properties\":{\"batt\":{\"unit\":\"%\",\"name\":\"battery\"}}}";
/*R""""(
{
   "properties":{
      "batt":{
         "unit":"%",
         "name":"battery"
      }
   }
})"""";*/
